<?php

/**
 * Define the OG Menu plugin
 */
$plugin = array(
  'title' => t('OG Menu pane'),
  'description' => t('This pane renders a OG Menu'),
  // 'single' => TRUE means has no subtypes.
  'single' => TRUE,
  // Constructor.
  'content_types' => array('og_menu_pane_content_type'),
  // Name of a function which will render the block.
  'render callback' => 'og_menu_pane_content_type_render',
  'edit form' => 'og_menu_pane_content_type_edit_form',
  // Add our content type to Organic Groups
  'category' => array(t('Organic Groups'), -9),
  'required context' => new ctools_context_required(t('Organic groups membership: Group gid'), 'group'),
  'context' => 'og_group_from_node_context',
);

/**
 * Run-time rendering of the OG Menu content type
 */
function og_menu_pane_content_type_render($subtype, $conf, $args, $context) {
  // We require a context for this pane to render
  if (empty($context->data)) {
    return FALSE;
  }
  
  // Get the gid from group that is available in the context
  $gid = $context->data->gid;
  // Get the OG menu for the group
  $menus = og_menu_get_menus(array($gid));
  $menu = array_shift($menus);
  
  if ($menu) {
    $block = new stdClass();
    $block->title = check_plain($menu->mtitle);
    // Link the pane title to the group if this has been set in the pane configuration.
    if (isset($conf['og_menu_pane_block_links']) && $conf['og_menu_pane_block_links']) {
      $block->title_link = 'node/' . $context->data->etid;
    }
    
    $block->content = menu_tree($menu->mname);
    return $block;
  }
  // If no menu was found return
  else {
    return FALSE;
  }
}

/**
 * Edit form.
 */
function og_menu_pane_content_type_edit_form($form, &$form_state) {
  $conf = $form_state['conf'];
  $form['og_menu_pane_block_links'] = array(
    '#type' => 'checkbox',
    '#title' => t('Link the title to group node'),
    '#default_value' => !empty($conf['og_menu_pane_block_links']) ? $conf['og_menu_pane_block_links'] : '',
    '#prefix' => '<div class="clear-block no-float">',
    '#suffix' => '</div>',
  );
  return $form;
}

/**
 * Implements hook_form_submit().
 */
function og_menu_pane_content_type_edit_form_submit(&$form, &$form_state) {
  foreach (element_children($form) as $key) {
    if (!empty($form_state['values'][$key])) {
      $form_state['conf'][$key] = $form_state['values'][$key];
    }
  }
}
